@@ -149,18 +149,15 @@ function execQuery($conn, $sql)
  */
 function NodeActive($nodeNum)
 {
-    $params = readConfigParams(array(
-        'backend_hostname', 'backend_port', 'backend_weight',
-        'health_check_user', 'health_check_password', 'health_check_database'
-    ));
+    $params = readConfigParams();
+    $perNodeParams = getPerNodeHealthCheck($nodeNum);
 
     $conn = openDBConnection(array(
         'host'     => $params['backend_hostname'][$nodeNum],
         'port'     => $params['backend_port'][$nodeNum],
-        'dbname'   => (paramExists('health_check_database')) ?
-                       $params['health_check_database'] : 'template1',
-        'user'     => $params['health_check_user'],
-        'password' => $params['health_check_password'],
+        'dbname'   => $perNodeParams['health_check_database'],
+        'user'     => $perNodeParams['health_check_user'],
+        'password' => $perNodeParams['health_check_password'],
         'connect_timeout' => _PGPOOL2_PG_CONNECT_TIMEOUT,
     ));
 
@@ -177,8 +174,15 @@ function NodeActive($nodeNum)
  */
 function NodeStandby($nodeNum)
 {
-    if (isMasterSlaveMode() == FALSE || useStreaming() == FALSE) {
-        return -1;
+    if (hasBackendClusteringMode()){
+        $params = readConfigParams(array('backend_clustering_mode'));
+        if ($params['backend_clustering_mode'] != 'streaming_replication') {
+            return -1;
+        }
+    } else {
+        if (isMasterSlaveMode() == FALSE || useStreaming() == FALSE) {
+            return -1;
+        }
     }
 
     $params = readConfigParams(array(
@@ -327,7 +331,8 @@ function readConfigParams($paramList = array())
 {
     $rtn = array();
     global $pgpoolConfigParam, $pgpoolConfigBackendParam,
-           $pgpoolConfigWdOtherParam, $pgpoolConfigHbDestinationParam;
+           $pgpoolConfigWdOtherParam, $pgpoolConfigHbDestinationParam,
+           $pgpoolConfigWdNodeParam, $pgpoolConfigWdHbNodeParam;
 
     // Try to read pgpool.conf
     $configFile = @file(_PGPOOL2_CONFIG_FILE);
@@ -339,7 +344,8 @@ function readConfigParams($paramList = array())
 
     // Defined array in definePgpoolConfParam.php
     $defines_arr = $pgpoolConfigParam + $pgpoolConfigBackendParam +
-                   $pgpoolConfigWdOtherParam + $pgpoolConfigHbDestinationParam;
+                   $pgpoolConfigWdOtherParam + $pgpoolConfigHbDestinationParam +
+                   $pgpoolConfigWdNodeParam + $pgpoolConfigWdHbNodeParam;
 
     $arr = array();
     // Convert lines in files to array
@@ -520,6 +526,31 @@ function paramExists($param)
 
     /* Add */
     switch ($param) {
+        // params added in 4.2
+        case 'backend_clustering_mode':
+        case 'ssl_crl_file':
+        case 'ssl_passphrase_command':
+        case 'log_disconnections':
+        case 'logging_collector':
+        case 'log_directory':
+        case 'log_filename':
+        case 'log_file_mode':
+        case 'log_truncate_on_rotation':
+        case 'log_rotation_age':
+        case 'log_rotation_size':
+        case 'read_only_function_list':
+        case 'write_function_list':
+        case 'primary_routing_query_pattern_list':
+        case 'dml_adaptive_object_relationship_list':
+        case 'hostname':
+        case 'pgpool_port':
+        case 'heartbeat_hostname':
+        case 'heartbeat_port':
+        case 'cache_safe_memqcache_table_list':
+        case 'cache_unsafe_memqcache_table_list':
+            $add_version = 4.2;
+            break;
+
         // params added in 4.1
         case 'reserved_connections':
         case 'backend_application_name':
@@ -689,6 +720,26 @@ function paramExists($param)
 
     /* Delete */
     switch ($param) {
+        // params deleted in 4.2
+        case 'replication_mode':
+        case 'master_slave_mode':
+        case 'master_slave_sub_mode':
+        case 'white_function_list':
+        case 'black_function_list':
+        case 'black_query_pattern_list':
+        case 'wd_hostname':
+        case 'wd_port':
+        case 'wd_heartbeat_port':
+        case 'heartbeat_destination':
+        case 'heartbeat_destination_port':
+        case 'white_memqcache_table_list':
+        case 'black_memqcache_table_list':
+        case 'other_pgpool_hostname':
+        case 'other_pgpool_port':
+        case 'other_wd_port':
+            $del_version = 4.2;
+            break;
+
         // params deleted in 4.0
         case 'fail_over_on_backend_error':
             $del_version = 4.0;
@@ -742,13 +793,89 @@ function paramExists($param)
     return $rtn;
 }
 
+function getPerNodeHealthCheck($nodeNum){
+    $rtn = array();
+    $params = readConfigParams();
+
+    $period = $params['health_check_period'];
+    if(isset($params['health_check_period' . $nodeNum])
+       && $params['health_check_period' . $nodeNum] != '')
+    {
+        $period = $params['health_check_period' . $nodeNum];
+    }
+
+    $timeout = $params['health_check_timeout'];
+    if(isset($params['health_check_timeout' . $nodeNum])
+       && $params['health_check_timeout' . $nodeNum] != '')
+    {
+        $timeout = $params['health_check_timeout' . $nodeNum];
+    }
+
+    $user = $params['health_check_user'];
+    if(isset($params['health_check_user' . $nodeNum])
+       && $params['health_check_user' . $nodeNum] != '')
+    {
+        $user = $params['health_check_user' . $nodeNum];
+    }
+
+    $password = $params['health_check_password'];
+    if(isset($params['health_check_password' . $nodeNum])
+       && $params['health_check_password' . $nodeNum] != '')
+    {
+        $password = $params['health_check_password' . $nodeNum];
+    }
+
+    $database = 'template1';
+    if(isset($params['health_check_database' . $nodeNum])
+       && $params['health_check_database' . $nodeNum] != '')
+    {
+        $database = $params['health_check_database' . $nodeNum];
+    }else{
+        $database = ($params['health_check_database'] != '') ?
+                     $params['health_check_database'] : 'template1';
+    }
+
+    $max_retries = $params['health_check_max_retries'];
+    if(isset($params['health_check_max_retries' . $nodeNum])
+       && $params['health_check_max_retries' . $nodeNum] != '')
+    {
+        $max_retries = $params['health_check_max_retries' . $nodeNum];
+    }
+
+    $retry_delay = $params['health_check_retry_delay'];
+    if(isset($params['health_check_retry_delay' . $nodeNum])
+       && $params['health_check_retry_delay' . $nodeNum] != '')
+    {
+        $retry_delay = $params['health_check_retry_delay' . $nodeNum];
+    }
+
+    $connect_timeout = $params['connect_timeout'];
+    if(isset($params['connect_timeout' . $nodeNum])
+       && $params['connect_timeout' . $nodeNum] != '')
+    {
+        $connect_timeout = $params['connect_timeout' . $nodeNum];
+    }
+
+    $rtn = array(
+        'health_check_period' => $period,
+        'health_check_timeout' => $timeout,
+        'health_check_user' => $user,
+        'health_check_password' => $password,
+        'health_check_database' => $database,
+        'health_check_max_retries' => $max_retries,
+        'connect_timeout' => $connect_timeout,
+        'health_check_retry_delay' => $retry_delay
+    );
+    return $rtn;
+}
+
 /* --------------------------------------------------------------------- */
 /* function (mode)                                                       */
 /* --------------------------------------------------------------------- */
 
 function versions()
 {
-    return array('4.1', '4.0', '3.7', '3.6', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
+    return array('4.2', '4.1', '4.0', '3.7', '3.6', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
                  '2.3', '2.2', '2.1', '2.0');
 }
 
@@ -757,26 +884,45 @@ function versions()
  */
 function isReplicationMode()
 {
-    $params = readConfigParams(array('replication_mode'));
-
-    if (isTrue($params['replication_mode'])) {
-        return TRUE;
+    if (hasBackendClusteringMode()){
+        $params = readConfigParams(array('backend_clustering_mode'));
+        if ($params['backend_clustering_mode'] == 'native_replication_mode'){
+            return TRUE;
+        } else {
+            return FALSE;
+        }
     } else {
-        return FALSE;
-    }
-}
+        $params = readConfigParams(array('replication_mode'));
 
+        if (isTrue($params['replication_mode'])) {
+            return TRUE;
+        } else {
+            return FALSE;
+        }
+	}
+}
 /**
  * Whether pgpool is operating in the master slave mode or not?
  */
 function isMasterSlaveMode()
 {
-    $params = readConfigParams(array('master_slave_mode'));
-
-    if (isTrue($params['master_slave_mode'])) {
-        return TRUE;
+    if (hasBackendClusteringMode()){
+        $params = readConfigParams(array('backend_clustering_mode'));
+        if ($params['backend_clustering_mode'] == 'streaming_replication'
+            || $params['backend_clustering_mode'] == 'logical_replication'
+            || $params['backend_clustering_mode'] == 'slony') {
+            return TRUE;
+        } else {
+            return FALSE;
+        }
     } else {
-        return FALSE;
+        $params = readConfigParams(array('master_slave_mode'));
+
+        if (isTrue($params['master_slave_mode'])) {
+            return TRUE;
+        } else {
+            return FALSE;
+        }
     }
 }
 
@@ -824,6 +970,14 @@ function useSyslog()
     }
 }
 
+/**
+ * Return if pgpool has Backend Clustering Mode
+ */
+function hasBackendClusteringMode()
+{
+    return (4.2 <= _PGPOOL2_VERSION);
+}
+
 /**
  * Return if pgpool has watchdog feature
  */
@@ -859,10 +1013,21 @@ function getMultiParams()
     if (paramExists('backend_flag')) {
         $rtn['backend'][] = 'backend_flag';
     }
+    if (paramExists('other_pgpool_hostname')) {
+        $rtn['other_pgpool'] = array('other_pgpool_hostname', 'other_pgpool_port', 'other_wd_port');
+    }
 
-    $rtn['other_pgpool'] = array('other_pgpool_hostname', 'other_pgpool_port', 'other_wd_port');
+    if (paramExists('heartbeat_destination')) {
+        $rtn['heartbeat'] = array('heartbeat_destination', 'heartbeat_destination_port', 'heartbeat_device');
+    }
 
-    $rtn['heartbeat'] = array('heartbeat_destination', 'heartbeat_destination_port', 'heartbeat_device');
+    if (paramExists('hostname')) {
+        $rtn['watchdog_node'] = array('hostname', 'wd_port', 'pgpool_port');
+    }
+
+    if (paramExists('heartbeat_hostname')){
+        $rtn['watchdog_heartbeat'] = array('heartbeat_hostname', 'heartbeat_port', 'heartbeat_device');
+    }
 
     return $rtn;
 }
@@ -881,13 +1046,13 @@ function showPerNodeHC()
 function getPerNodeHealthCheckParams()
 {
     $rtn = array();
-    $rtn = array('health_check_period', 
-                 'health_check_timeout', 
-                 'health_check_user', 
-                 'health_check_password', 
-                 'health_check_database', 
-                 'health_check_max_retries', 
-                 'health_check_retry_delay', 
+    $rtn = array('health_check_period',
+                 'health_check_timeout',
+                 'health_check_user',
+                 'health_check_password',
+                 'health_check_database',
+                 'health_check_max_retries',
+                 'health_check_retry_delay',
                  'connect_timeout');
 
     return $rtn;
@@ -910,10 +1075,26 @@ function isTrue($value)
 
 function definedHealthCheckParam($params, $param_name, $backend_num)
 {
-    return isset($params[$param_name . $backend_num]) ? 
+    return isset($params[$param_name . $backend_num]) ?
             $param_name . $backend_num : null;
 }
 
+function isHealthCheckValid($params)
+{
+    if (isset($params["health_check_period"]) && $params["health_check_period"] != 0) {
+        return TRUE;
+    }
+
+    foreach ($params["backend_hostname"] as $backend_num => $value) {
+        if (isset($params["health_check_period" . $backend_num]) &&
+            $params["health_check_period" . $backend_num] != 0) {
+            return TRUE;
+        }
+    }
+
+    return FALSE;
+}
+
 function errorPage($errorCode)
 {
     global $tpl;
