@@ -44,8 +44,6 @@ if (isset($_POST['action'])) {
 // check version
 if (isset($_POST['version']) && $_POST['version']) {
     $version = $_POST['version'];
-} else {
-    $version = NULL;
 }
 
 // check pgpool.conf
@@ -481,7 +479,7 @@ else {
 
 function versions()
 {
-    return array('4.1', '4.0', '3.7', '3.6', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
+    return array('4.2', '4.1', '4.0', '3.7', '3.6', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
                  '2.3', '2.2', '2.1', '2.0');
 }
 
