@@ -29,15 +29,16 @@ $message = array(
 
     'descAllow_clear_text_frontend_auth' => 'If on, allow the Pgpool-II to use clear-text-password authentication with frontend clients',
     'descAllow_multiple_failover_requests_from_node' => 'If on, a single Pgpool-II node can cast multiple votes for the failover',
-    'descEnable_consensus_with_half_votes' => 'Apply majority rule for consensus and quorum computation at 50% of votes ' .
-                                              'in a cluster with even number of nodes',
     'descAllow_sql_comments' => 'If on, ignore SQL comments when judging if load balance or query cache is possible',
     'descApp_name_redirect_preference_list' => '"application name:node id" pairs to specify the node id when the application is used',
     'descArping_path' => 'The path of a command to send an ARP request after the virtual IP is switched',
     'descArping_cmd' => 'The ommand to send an ARP request after the virtual IP is switched',
     'descAuthentication_timeout' => 'Timeout in seconds to complete client authentication',
+    'descAuto_failback' => 'Reattach dettached backend node automatically if replication_state is \'streaming\'',
+    'descAuto_failback_interval' => 'Interval of executing auto_failback in seconds',
     'descBackend_flag' => 'Allow failover and detach or not',
     'descBackend_application_name' => 'walsender\'s application_name, used for "show pool_nodes" command',
+    'descBackend_clustering_mode' => 'The method to sync PostgreSQL servers',
     'descBackend_hostname' => 'The real PostgreSQL server name pgpool could connect',
     'descBackend_port' => 'The port number where real PostgreSQL server is running on',
     'descBackend_socket_dir' => 'The socket directory PostgreSQL could connect',
@@ -46,10 +47,10 @@ $message = array(
     'descBlack_function_list' => 'Comma separated functions which write to database',
     'descBlack_memqcache_table_list' => 'Comma separated list of table names not to be cached',
     'descBlack_query_pattern_list' => 'Semicolon separated list of SQL patterns not to be load balanced',
+    'descCache_safe_memqcache_table_list' => 'Comma separated list of table names to be cached',
+    'descCache_unsafe_memqcache_table_list' => 'Comma separated list of table names not to be cached',
     'descCheck_temp_table' => 'If on, enable temporary table check in SELECT statements',
     'descCheck_unlogged_table' => 'If on, enable unlogged table check in SELECT statements.',
-    'descEnable_shared_relcache' => 'If on, relation cache stored in memory cache, the cache is shared among child process',
-    'descRelcache_query_target' => 'Target node to send relcache queries',
     'descChild_life_time' => 'Life of an idle child process in seconds',
     'descChild_max_connections' => 'If child_max_connections connections were received, child exits',
     'descClear_memqcache_on_escalation' => 'If on, watchdog clears all the query cache in the shared memory when pgpool-II escaltes to active',
@@ -67,9 +68,12 @@ $message = array(
     'descDelegate_IP' => 'The virtual IP address (VIP) of pgpool-II ',
     'descDetach_false_primary' => 'If on, detach false primary node',
     'descDisable_load_balance_on_write' => 'Specify load balance behavior when write query is issued',
-    'descStatement_level_load_balance' => 'Enables statement level load balancing',
+    'descDml_adaptive_object_relationship_list' => 'The list of dependent object names',
+    'descEnable_consensus_with_half_votes' => 'Apply majority rule for consensus and quorum computation at 50% of votes ' .
+                                              'in a cluster with even number of nodes',
     'descEnable_pool_hba' => 'Use host-based authentication',
     'descEnable_query_cache' => 'Perform query cache',
+    'descEnable_shared_relcache' => 'If on, relation cache stored in memory cache, the cache is shared among child process',
     'descFailover_command' => 'Command to execute when detaching a node',
     'descFailback_command' => 'Command to execute when attaching a node',
     'descFailover_if_affected_tuples_mismatch' => 'Fail over due to disagreement with the number of affected tuples '.
@@ -79,9 +83,12 @@ $message = array(
     'descFail_over_on_backend_error' => 'Fail over when socket communication error to backend occurs',
     'descFailover_on_backend_error' => 'Fail over when socket communication error to backend occurs',
     'descFollow_master_command' => 'Command to run only after a master failover',
+    'descFollow_primary_command' => 'Command to run only after a primary failover',
     'descHeartbeat_destination' => 'The destination of heartbeat signals. Specify by hostname or IP address.',
     'descHeartbeat_destination_port' => 'The port number of the destination of heartbeat signals.',
     'descHeartbeat_device' => 'The network device name for sending heartbeat signals',
+    'descHeartbeat_hostname' => 'The destination of heartbeat signals. Specify by hostname or IP address.',
+    'descHeartbeat_port' => 'The port number of the destination of heartbeat signals.',
     'descHealth_check_database' => 'The database name to perform health check',
     'descHealth_check_period' => 'Specifies the interval for next health checking. 0 means no health checking, '.
                                  '-1 means no wait',
@@ -92,7 +99,9 @@ $message = array(
     'descHealth_check_max_retries' => 'The maximum number of times to retry a failed health check before'.
                                       ' giving up and initiating failover',
     'descHealth_check_retry_delay' => 'The amount of time (in seconds) to sleep between failed health check retries',
+    'descHostname' => 'The hostname or IP address of watchdog node',
     'descIfconfig_path' => 'The path of a command to switch the IP address',
+    'descIf_cmd_path' => 'The path of a command to switch the IP address',
     'descIf_down_cmd' => 'The command to bring down the virtual IP',
     'descIf_up_cmd' => 'The command to bring up the virtual IP',
     'descIgnore_leading_white_space' => 'If true, ignore leading white spaces of each query while pgpool judges '.
@@ -103,19 +112,25 @@ $message = array(
     'descListen_backlog_multiplier' => 'The number of preforked pgpool-II server processes',
     'descLoad_balance_mode' => 'Perform load balancing for SELECT',
     'descLobj_lock_table' => 'Specifies table name lock used when rewriting lo_create in replication mode',
+    'descLogdir' => 'The directory name to store pgpool_status file',
+    'descLogging_collector' => 'Capture log mesages sent to stderr and redirect into log file',
     'descLog_client_messages' => 'If true, print client messages to the log',
     'descLog_connections' => 'If true, incoming connections will be printed to the log',
     'descLog_destination' => 'Where to log',
+    'descLog_directory' => 'The directory name to store pgpool\'s log files',
     'descLog_error_verbosity' => 'The amount of detail emitted for each message that is logged',
+    'descLog_filename' => 'The names of log files',
+    'descLog_file_mode' => 'The permissions for log files',
     'descLog_line_prefix' => 'printf-style string that is output at the beginning of each log line',
     'descLog_min_messages' => 'Which minimum message levels are emitted to log',
+    'descLog_per_node_statement' => 'If true, print all statements to the log per DB node',
+    'descLog_rotation_age' => 'The maximum amount of time (min) to use an individual log file',
+    'descLog_rotation_size' => 'The maximum amount of size (kB) to use an individual log file',
     'descLog_standby_delay' => 'Frequency to log the standby delay',
     'descLog_hostname' => 'If true, client\'s hostname will be shown in ps status and in a connection log '.
                           'if log_connections is true',
     'descLog_statement' => 'If true, print all statements to the log',
-    'descLogdir' => 'The directory name to store pgpool\'s log files',
-    'descLog_per_node_statement' => 'If true, print all statements to the log per DB node',
-    'descPid_file_name' => 'The pid file name',
+    'descLog_truncate_on_rotation' => 'Pgpool-II truncate (overwrite), rather than append to, any existing log file of the same name',
     'descMaster_slave_mode' => 'Run in master/slave mode',
     'descMaster_slave_sub_mode' => 'The way to replicare in Master/slave mode',
     'descMax_pool' => 'Number of connection pools each pgpool server process are keeping',
@@ -136,49 +151,54 @@ $message = array(
     'descOther_pgpool_port' => 'The port number for pgpool on pgpool-II server to be monitored',
     'descOther_wd_port' => 'The port number for watchdog on pgpool-II server to be monitored',
     'descParallel_mode' => 'Run in parallel mode',
+    'descPid_file_name' => 'The pid file name',
     'descPing_path' => 'The path of ping command for monitoring connection to the upper servers',
     'descPcp_port' => 'The port number where pcp is running on',
     'descPcp_socket_dir' => 'The socket directory pcp could connect',
     'descPcp_timeout' => 'When there is no response in this time from client, it disconnects and stop',
     'descPcp_listen_addresses' => 'the hostname or IP address, on which pcp process will accept TCP/IP connections.',
     'descPgpool2_hostname' => 'Pgpool2 server name where running on',
+    'descPgpool_port' => 'The port number where pgpool is running on',
     'descPool_passwd' => 'File name of pool_passwd for md5 authentication',
     'descPort' => 'The port number where pgpool is running on',
+    'descPrimary_routing_query_pattern_list' => 'Semicolon separated list of SQL patterns not to be load balanced',
     'descPrint_timestamp' => 'If true, timestamp is added to each log line',
+    'descRead_only_function_list' => 'Comma separated functions those do not write to Database',
     'descRecovery_user' => 'PostgreSQL user name for online recovery',
     'descRecovery_password' => 'PostgreSQL user password for online recovery',
     'descRecovery_1st_stage_command' => 'Recovery command to be excuted on the first stage',
     'descRecovery_2nd_stage_command' => 'Recovery command to be excuted on the second stage',
     'descRecovery_timeout' => 'Number of seconds to wait for online recovery to complete. 0 means no wait',
     'descRelcache_expire' => 'Life time of relation cache in seconds',
+    'descRelcache_query_target' => 'Target node to send relcache queries',
     'descRelcache_size' => 'Size of relation cache in bytes',
     'descReplication_mode' => 'Set this to true if you are going to use replication functionality',
     'descReplication_stop_on_mismatch' => 'Stop replication mode on data mismatch between master and secondary',
     'descReplicate_select' => 'If true, replicate SELECT queries. If false, send only to master',
     'descReplication_timeout' => 'In non strict replication mode, there will be a risk of deadlock. '.
                                  'Timeout in second for monitoring the deadlock',
+    'descReset_query_list' => 'Semicolon separated SQL commands to be issued at the end of session',
+    'descReserved_connections' => 'Number of reserved connections',
     'descSearch_primary_node_timeout' => 'the maximum amount of time in seconds to search'.
                                          'for a primary node when a failover scenario occurs.',
-    'descAuto_failback' => 'Reattach dettached backend node automatically if replication_state is \'streaming\'',
-    'descAuto_failback_interval' => 'Interval of executing auto_failback in seconds',
     'descSerialize_accept' => 'Whether to serialize accept() call for incoming client connections.',
-    'descReset_query_list' => 'Semicolon separated SQL commands to be issued at the end of session',
-    'descSerialize_accept' => 'Whether to serialize accept() call for incoming client connections',
-    'descReserved_connections' => 'Number of reserved connections',
-    'descSsl' => 'The frontend connection',
-    'descSsl_ca_cert' => 'Path to the SSL private key file',
-    'descSsl_ca_cert_dir' => 'Path to the SSL public certificate file',
-    'descSsl_cert' => 'Path to the SSL private key file',
-    'descSsl_key' => 'Path to the SSL private key file',
-    'descSsl_ciphers' => 'Allowed SSL ciphers',
-    'descSsl_prefer_server_ciphers' => 'Use server\'s SSL cipher preferences, rather than the client\'s',
-    'descSsl_ecdh_curve' => 'Name of the curve to use in ECDH key exchange',
-    'descSsl_dh_params_file' => 'Name of the file containing Diffie-Hellman parameters',
     'descSocket_dir' => 'The socket directory pgpool could connect',
     'descSr_check_database' => 'The database to perform streaming replication delay check',
     'descSr_check_period' => 'Interval between the streaming replication delay checks in seconds.',
     'descSr_check_user' => 'User name to perform streaming replication check',
     'descSr_check_password' => 'Password of the user to perform streaming replication check',
+    'descSsl' => 'The frontend connection',
+    'descSsl_ca_cert' => 'Path to the SSL private key file',
+    'descSsl_ca_cert_dir' => 'Path to the SSL public certificate file',
+    'descSsl_cert' => 'Path to the SSL private key file',
+    'descSsl_key' => 'Path to the SSL private key file',
+    'descSsl_crl_file' => 'Specifies the file containing the SSL server certificate revocation list (CRL).',
+    'descSsl_ciphers' => 'Allowed SSL ciphers',
+    'descSsl_prefer_server_ciphers' => 'Use server\'s SSL cipher preferences, rather than the client\'s',
+    'descSsl_ecdh_curve' => 'Name of the curve to use in ECDH key exchange',
+    'descSsl_dh_params_file' => 'Name of the file containing Diffie-Hellman parameters',
+    'descSsl_passphrase_command' => 'Sets an external command to be invoked when a passphrase for decrypting an SSL file such as a private key needs to be obtained.',
+    'descStatement_level_load_balance' => 'Enables statement level load balancing',
     'descSyslog_facility' => 'Syslog local facility',
     'descSyslog_ident' => 'Syslog program identification string',
     'descSystem_db_dbname' => 'The database name of system database',
@@ -215,6 +235,7 @@ $message = array(
                          'to select master watchdog node',
     'descWhite_function_list' => 'Comma separated functions those do not write to Database',
     'descWhite_memqcache_table_list' => 'Comma separated list of table names to be cached',
+    'descWrite_function_list' => 'Comma separated functions those write to Database',
 
     'errAlreadyExist' => 'It already exists.',
     'errFileNotExecutable' => 'File not executable',
@@ -264,6 +285,7 @@ $message = array(
     'strAdminPassword' => 'Password',
     'strBack' => 'Back',
     'strBackendPid' => 'Backend Pid',
+    'strBackendClusteringMode' => 'Backend Clustering Mode',
     'strCancel' => 'Cancel',
     'strChangePassword' => 'Change Password',
     'strClear' => 'Clear',
@@ -320,7 +342,7 @@ $message = array(
     'strLogShowAll' => 'Show the All Lines',
     'strLogShowLines' => 'Lines',
     'strMasterServer' => 'Master Server',
-    'strMasterSlaveMode' => 'Master Slave mode',
+    'strMasterSlaveMode' => 'Master Slave Mode',
     'strMeasures' => 'Measures',
     'strNodeInfo' => 'Node Info.',
     'strNodeStatus' => 'Node Status',
@@ -360,6 +382,7 @@ $message = array(
     'strProcInfo' => 'Process Info.',
     'strProcTime' => 'Process Start Time',
     'strPromote' => 'Promote',
+    'strPromotePrimary' => 'Promote',
     'strProtocolMajorVersion' => 'Protocol Major Version',
     'strProtocolNinorVersion' => 'Protocol Minor Version',
     'strQueryCache' => 'Query Cache',
@@ -381,7 +404,7 @@ $message = array(
     'strSecondaryServer' => 'Secondary Server',
     'strSetting' => 'pgpoolAdmin Setting',
     'strSetup' => 'Setup',
-    'strSlonyMode' => 'Slony-I mode',
+    'strSlonyMode' => 'Slony-I Mode',
     'strStandbyRunning' => 'Running as standby server',
     'strStartOption' => 'Start Option',
     'strStartPgpool' => 'Start pgpool',
@@ -392,7 +415,7 @@ $message = array(
     'strStopPgsql' => 'Stop',
     'strStopPgsqlOption' => 'Stop PostgreSQL Option',
     'strStoppingNow' => 'Not Running',
-    'strStreamingRepMode' => 'Streaming Replication mode',
+    'strStreamingRepMode' => 'Streaming Replication Mode',
     'strSummary' => 'Summary',
     'strSystemDb' => 'Partitioning Rule',
     'strSystemCatalog' => 'System catalog',
@@ -410,6 +433,10 @@ $message = array(
     'strWdInit' => 'Not Started',
     'strWdStandby' => 'Standby',
     'strWeight' => 'Weight',
+    'strLogocalRepMode' => 'Logical Replication Mode',
+    'strNativeRepMode' => 'Native Replication Mode',
+    'strRawMode' => 'RAW Mode',
+
 
     'e1' => 'pgmgt.conf.php not found.',
     'e2' => 'Message catalog not found.',
