@@ -29,26 +29,28 @@ $message = array(
 
     'descAllow_clear_text_frontend_auth' => 'Pgpool-IIがフロントエンドクライアントとクリアテキストパスワード認証を許可',
     'descAllow_multiple_failover_requests_from_node' => '単一のPgpool-IIノードが複数のフェイルオーバ投票ができるどうか',
-    'descEnable_consensus_with_half_votes' => 'クォーラムとフェイルオーバにおける合意を解決する際に、どのように多数決ルールにおける計算を行うかを設定',
     'descAllow_sql_comments' => '負荷分散やクエリキャッシュができるかどうかの判定の際に、SQLコメントを無視するかどうか',
     'descApp_name_redirect_preference_list' => 'アプリケーション名によって負荷分散をしたいノード番号を、"アプリケーション名:ノード番号"で指定',
     'descArping_path' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンドのパス',
     'descArping_cmd' => 'IP アドレス切り替え後に ARP リクエストを送信するコマンド',
     'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
-    'descBackend_flag' => 'フェイルオーバやデタッチの可否',
+    'descAuto_failback' => 'ダウンしたスタンバイノードを自動で復帰させるかどうか',
+    'descAuto_failback_interval' => '自動フェイルバックの実行間隔の最小時間(秒)',
     'descBackend_application_name' => 'walsenderのために使用するapplication_nameを設定',
+    'descBackend_clustering_mode' => 'バックエンドのPostgreSQLの同期をとる方法',
+    'descBackend_data_directory' => 'PostgreSQLサーバのデータベースディレクトリ',
+    'descBackend_flag' => 'フェイルオーバやデタッチの可否',
     'descBackend_hostname' => 'pgpoolが接続するPostgreSQLサーバ(postmaster)が動いているホスト名',
     'descBackend_port' => 'PostgreSQLサーバのポート番号',
     'descBackend_socket_dir' => 'PostgreSQLサーバのUnix domain socketのディレクトリ',
     'descBackend_weight' => 'ロードバランスモード時のSELECTを振り分ける「重み」の定義',
-    'descBackend_data_directory' => 'PostgreSQLサーバのデータベースディレクトリ',
     'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
     'descBlack_memqcache_table_list' => 'SELECT結果をキャッシュしたくないテーブル名のカンマ区切りのリスト',
     'descBlack_query_pattern_list' => '負荷分散を行わないセミコロン区切りのSQLパターンリスト',
+    'descCache_safe_memqcache_table_list' => 'SELECT結果をキャッシュしたいテーブル名のカンマ区切りのリスト',
+    'descCache_unsafe_memqcache_table_list' => '負荷分散を行わないセミコロン区切りのSQLパターンリスト',
     'descCheck_temp_table' => '一時テーブルかどうかをチェック',
     'descCheck_unlogged_table' => 'unloggedテーブルかどうかをチェック',
-    'descEnable_shared_relcache' => 'クエリキャッシュを利用して子プロセス間でリレーションキャッシュを共有するかどうか',
-    'descRelcache_query_target' => 'リレーションキャッシュを作成するためのクエリを送る先のノード',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
     'descClear_memqcache_on_escalation' => 'アクティブ昇格時に共有メモリ上のクエリキャッシュを削除するかどうか',
@@ -64,9 +66,11 @@ $message = array(
     'descDelegate_IP' => '仮想 IP アドレス',
     'descDetach_false_primary' => '不正なプライマリを切り離すかどうか',
     'descDisable_load_balance_on_write' => '更新クエリが発行された時の負荷分散の振る舞いを指定',
-    'descStatement_level_load_balance' => '参照クエリごとに負荷分散先を決めるかどうか',
+    'descDml_adaptive_object_relationship_list' => '依存オブジェクトのリスト',
+    'descEnable_consensus_with_half_votes' => 'クォーラムとフェイルオーバにおける合意を解決する際に、どのように多数決ルールにおける計算を行うかを設定',
     'descEnable_pool_hba' => 'クライアント認証機能の有無',
     'descEnable_query_cache' => 'クエリキャッシュ機能の有無',
+    'descEnable_shared_relcache' => 'クエリキャッシュを利用して子プロセス間でリレーションキャッシュを共有するかどうか',
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
     'descFailback_command' => 'ノード復帰時に起動するコマンド',
     'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
@@ -75,9 +79,12 @@ $message = array(
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descFailover_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descFollow_master_command' => 'マスタのフェイルオーバ後に実行するコマンド',
+    'descFollow_primary_command' => 'プライマリのフェイルオーバ後に実行するコマンド',
     'descHeartbeat_destination' => 'ハートビート信号の送信先ホスト名または IP アドレス',
     'descHeartbeat_destination_port' => 'ハートビート信号の送信先ポート番号',
     'descHeartbeat_device' => 'ハートビートの送受信に用いるネットワークデバイス名',
+    'descHeartbeat_hostname' => 'ハートビート信号の送信先ホスト名または IP アドレス',
+    'descHeartbeat_port' => 'ハートビート信号の送信先ポート番号',
     'descHealth_check_database' => 'ヘルスチェックを行う対象のデータベース名',
     'descHealth_check_period' => 'ヘルスチェックを行なう間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
@@ -85,6 +92,7 @@ $message = array(
     'descHealth_check_password' => 'ヘルスチェックを行うためのPostgreSQLパスワード',
     'descHealth_check_max_retries' => 'ヘルスチェックに失敗した後にリトライする回数',
     'descHealth_check_retry_delay' => 'ヘルスチェックのリトライの間の間隔（秒）',
+    'descHostname' => 'watchdog ノードのホスト名または IP アドレス',
     'descIfconfig_path' => 'ifconfig コマンドのパス',
     'descIf_cmd_path' => 'if コマンドのパス',
     'descIf_down_cmd' => '仮想 IP を停止するために実行するコマンド',
@@ -95,18 +103,25 @@ $message = array(
     'descListen_backlog_multiplier' => 'フロントエンドからpgpool-IIへの接続待ち行列の長さ',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
     'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
+    'descLogdir' => 'pgpool_statusファイルを格納するディレクトリのフルパス',
+    'descLogging_collector' => 'stderrに送られたログメッセージを捕捉しログファイルにリダイレクトする',
     'descLog_client_messages' => 'クライアントメッセージをログに出力',
     'descLog_connections' => '受信した接続のログを出力',
     'descLog_destination' => 'ログの出力先',
+    'descLog_directory' => 'ログファイルが作成されるディレクトリ',
+    'descLog_disconnections' => '接続終了した接続のログを出力',
     'descLog_error_verbosity' => '出力するログの詳細レベル',
+    'descLog_filename' => 'ログファイルのファイル名',
+    'descLog_file_mode' => 'ログファイルのパーミッション',
     'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
     'descLog_line_prefix' => '各ログ行頭の出力形式',
     'descLog_min_messages' => 'ログとして記録するログの詳細レベル',
+    'descLog_per_node_statement' => 'DBノード毎にSQL文をログ出力',
+    'descLog_rotation_age' => '個々のログファイルの寿命。指定した時間(分)を超えると新しいログファイルが生成される',
+    'descLog_rotation_size' => '個々のログファイルの容量。指定したサイズ(kB)を超えると新しいログファイルが生成される',
     'descLog_standby_delay' => 'スタンバイサーバの遅延をログに記録する',
     'descLog_statement' => 'SQL文をログ出力',
-    'descLogdir' => 'pgpoolの各種ログファイルを格納するディレクトリ',
-    'descLog_per_node_statement' => 'DBノード毎にSQL文をログ出力',
-    'descPid_file_name' => 'pidファイルの名前',
+    'descLog_truncate_on_rotation' => 'ログファイルの上書きを許可する',
     'descMaster_slave_mode' => 'マスタ/スレーブモードでpgpoolを運転',
     'descMaster_slave_sub_mode' => 'マスタ/スレーブモードの伝播方法',
     'descMax_pool' => 'pgpoolの各サーバプロセスがキープするPostgreSQLへの最大コネクション数',
@@ -132,42 +147,48 @@ $message = array(
     'descPcp_socket_dir' => 'pcpがコネクションを受け付けるUnix domain socketディレクトリ',
     'descPcp_timeout' => 'この時間内にクライアントから応答がない場合はコネクションを切断して終了',
     'descPgpool2_hostname' => 'pgpool2 が動作しているホスト名',
-    'descPool_passwd' => 'md5 認証で用いる認証ファイル',
+    'descPgpool_port' => 'pgpool のポート番号',
+    'descPid_file_name' => 'pidファイルの名前',
     'descPing_path' => 'ping コマンドのパス',
+    'descPool_passwd' => 'md5 認証で用いる認証ファイル',
     'descPort' => 'pgpoolがTCP/IPコネクションを受け付けるポート番号',
+    'descPrimary_routing_query_pattern_list' => '負荷分散を行わないセミコロン区切りのSQLパターンリスト',
     'descPrint_timestamp' => 'pgpoolのログにタイムスタンプを追加',
+    'descRead_only_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
     'descRecovery_user' => 'リカバリを行うためのPostgreSQLユーザ',
     'descRecovery_password' => 'リカバリを行うためのPostgreSQLユーザパスワード',
     'descRecovery_1st_stage_command' => 'オンラインリカバリ第1ステージで実行するコマンド',
     'descRecovery_2nd_stage_command' => 'オンラインリカバリ第2ステージで実行するコマンド',
     'descRecovery_timeout' => 'オンラインリカバリ終了までの待ち時間(秒)。0 は待ち時間無し',
     'descRelcache_expire' => 'システムカタログキャッシュの有効時間(秒)',
+    'descRelcache_query_target' => 'リレーションキャッシュを作成するためのクエリを送る先のノード',
     'descRelcache_size' => 'システムカタログキャッシュのサイズ(バイト)',
     'descReplication_mode' => 'レプリケーションモードの有効化',
     'descReplication_stop_on_mismatch' => 'マスタ/セカンダリ間のデータ不一致時に縮退運転',
     'descReplicate_select' => 'SELECT 文のレプリケーション',
     'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間。'.
                                  '厳密でないレプリケーションモードでは、デッドロックが発生しやすくなります。',
+    'descReserved_connections' => '(num_init_children - reserved_connections)以上のクライアントからの接続要求を拒否するかどうか',
     'descReset_query_list' => 'セッションが終了するときにコネクションを初期化するためのSQLコマンド',
     'descSearch_primary_node_timeout' => 'フェイルオーバーが起きた時にプライマリノードを検索する際のタイムアウト時間(秒)',
-    'descAuto_failback' => 'ダウンしたスタンバイノードを自動で復帰させるかどうか',
-    'descAuto_failback_interval' => '自動フェイルバックの実行間隔の最小時間(秒)',
     'descSerialize_accept' => 'クライアントからの接続受け付け時、accept() をシリアライズする',
-    'descReserved_connections' => '(num_init_children - reserved_connections)以上のクライアントからの接続要求を拒否するかどうか',
     'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
-    'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
-    'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
-    'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
-    'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
-    'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
-    'descSsl_ciphers' => 'セキュアな接続で使用できるSSL暗号スイートのリストを指定する',
-    'descSsl_prefer_server_ciphers' => 'クライアントではなく、サーバ指定のSSL暗号を選択するかどうか',
-    'descSsl_ecdh_curve' => 'ECDHキー交換で使われる曲線の名前を指定する',
-    'descSsl_dh_params_file' => '短命DH系SSL暗号で使用するディフィー・ヘルマンパラメータを格納するファイル名を指定する',
     'descSr_check_database' => 'ストリーミングレプリケーションの遅延チェックを行なう対象のデータベース名',
     'descSr_check_period' => 'ストリーミングレプリケーションの遅延チェックの間隔(秒)',
     'descSr_check_user' => 'ストリーミングレプリケーションの遅延チェックを行うユーザ',
     'descSr_check_password' => 'ストリーミングレプリケーションの遅延チェックを行うユーザのパスワード',
+    'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
+    'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
+    'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
+    'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
+    'descSsl_ciphers' => 'セキュアな接続で使用できるSSL暗号スイートのリストを指定する',
+    'descSsl_crl_file' => 'SSLサーバ証明書失効リスト(CRL)が入っているファイルのフルパス',
+    'descSsl_ecdh_curve' => 'ECDHキー交換で使われる曲線の名前を指定する',
+    'descSsl_dh_params_file' => '短命DH系SSL暗号で使用するディフィー・ヘルマンパラメータを格納するファイル名を指定する',
+    'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
+    'descSsl_passphrase_command' => '秘密鍵などのSSLファイルを複合する際にパスフレーズを要求された時に起動される外部コマンド',
+    'descSsl_prefer_server_ciphers' => 'クライアントではなく、サーバ指定のSSL暗号を選択するかどうか',
+    'descStatement_level_load_balance' => '参照クエリごとに負荷分散先を決めるかどうか',
     'descSyslog_facility' => 'Syslogのファシリティ',
     'descSyslog_ident' => 'Syslog中でのプログラム名',
     'descSystem_db_dbname' => 'System DBのデータベース名',
@@ -198,6 +219,7 @@ $message = array(
     'descWd_priority' => '自身の watchdog ノードがリーダに選ばれる優先度',
     'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
     'descWhite_memqcache_table_list' => 'SELECT結果をキャッシュしたいテーブル名のカンマ区切りのリスト',
+    'descWrite_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
 
     'errAlreadyExist' => 'すでに登録されています',
     'errFileNotExecutable' => 'コマンドを実行できません',
@@ -247,6 +269,7 @@ $message = array(
     'strAdminPassword' => '管理者パスワード',
     'strBack' => '戻る',
     'strBackendPid' => 'バックエンドプロセスID',
+    'strBackendClusteringMode' => 'バックエンドクラスタリングモード',
     'strCancel' => 'キャンセル',
     'strChangePassword' => 'パスワード変更',
     'strClear' => 'クリア',
@@ -343,6 +366,7 @@ $message = array(
     'strProcInfo' => 'プロセス情報',
     'strProcTime' => 'プロセススタート時刻',
     'strPromote' => 'マスタ昇格',
+    'strPromotePrimary' => 'プライマリ昇格',
     'strProtocolMajorVersion' => 'プロトコルメジャーバージョン',
     'strProtocolNinorVersion' => 'プロトコルマイナーバージョン',
     'strQueryCache' => 'クエリキャッシュ',
@@ -393,6 +417,10 @@ $message = array(
     'strWdInit' => '未起動',
     'strWdStandby' => 'スタンバイ',
     'strWeight' => 'ウェイト',
+    'strLogocalRepMode' => 'Logical Replicationモード',
+    'strNativeRepMode' => 'Native Replicationモード',
+    'strRawMode' => 'RAWモード',
+    'strSnapshotIsolationMode' => 'Snapshot Isolationモード',
 
     'e1' => 'pgmgt.conf.phpが見つかりません',
     'e2' => 'メッセージカタログが見つかりません',
