@@ -27,6 +27,7 @@ $message = array(
     'lang' => 'zh_cn',
     'strLang' => '简体中文',
 
+    'descAllow_clear_text_frontend_auth' => 'Pgpool-II 允许与前端进行明文密码认证',
     'descAllow_multiple_failover_requests_from_node' => '一个 Pgpool-II 节点是否能够投多个票',
     'descAllow_sql_comments' => '在判断能否负载均衡和查询缓存时，是否忽略SQL注释',
     'descApp_name_redirect_preference_list' => '对于想使用负载均衡功能的节点，用"数据库名:节点号"的形式指定',
@@ -41,6 +42,7 @@ $message = array(
     'descBackend_data_directory' => 'PostgreSQL 数据库目录',
     'descBlack_function_list' => '用逗号分隔的有写操作的函数',
     'descBlack_memqcache_table_list' => '指定一个以逗号分隔的表名的列表，用于使 SELECT 的结果不被缓存',
+    'descBlack_query_pattern_list' => '不被负载均衡的用分号分隔的 SQL 列表',
     'descCheck_temp_table' => '是否启用临时表检查',
     'descCheck_unlogged_table' => '检查是否是unlogged表',
     'descChild_life_time' => '空闲的子进程的生命期，单位为秒',
@@ -56,6 +58,8 @@ $message = array(
 	'descDebug_level' => '调试信息的详细级别',
     'descDelay_threshold' => '如果备用服务器的延迟超过了 delay_threshold ，任何查询都将只发送到主服务器',
     'descDelegate_IP' => '虚拟 IP 地址',
+    'descDetach_false_primary' => '是否切断不正确的主节点',
+    'descDisable_load_balance_on_write' => '指定执行更新查询后的负载均衡的行为',
     'descEnable_pool_hba' => '基于主机的认证',
     'descEnable_query_cache' => '执行查询缓存',
     'descFailover_command' => '断开一个节点时执行的命令',
@@ -64,6 +68,7 @@ $message = array(
     'descFailover_require_consensus' => '是否使用 quorum 投票来进行故障切换',
     'descFailover_when_quorum_exists' => '是否使用 quorum 机制来进行故障切换',
     'descFail_over_on_backend_error' => '与服务器发生套接字错误时进行故障切换',
+    'descFailover_on_backend_error' => '与服务器发生套接字错误时进行故障切换',
     'descFollow_master_command' => '在主节点发送故障切换后运行的命令',
     'descHeartbeat_destination' => '心跳信号发送目标的 IP 地址或主机名',
     'descHeartbeat_destination_port' => '心跳信号发送目标的端口号',
@@ -85,7 +90,8 @@ $message = array(
     'descListen_backlog_multiplier' => '前端程序连接 pgpool-II 的等待队列的长度',
     'descLoad_balance_mode' => '为 SELECT 进行负载均衡',
     'descLobj_lock_table' => '指定在复制模式中当重写 lo_create 时用于加锁的表名',
-	'descLog_connections' => '如果为 true，进入的连接信息将被打印到日志中',
+    'descLog_client_messages' => '如果为 true，前端信息将被写到日志中',
+    'descLog_connections' => '如果为 true，进入的连接信息将被写到日志中',
     'descLog_destination' => '记录日志的地方',
     'descLog_error_verbosity' => '写到服务器日志里的消息的详细程度',
 	'descLog_hostname' => '如果为 true ，备机的主机名将能够用 ps 命令显示，且当 log_connections 为 true 的时候，将记录备机的主机名到日志中',
